@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,6 +51,7 @@ package com.openexchange.apps.manifests.json.osgi;
 
 import java.util.List;
 import com.openexchange.apps.manifests.ComputedServerConfigValueService;
+import com.openexchange.apps.manifests.ManifestContributor;
 import com.openexchange.apps.manifests.ServerConfigMatcherService;
 
 /**
@@ -63,4 +64,6 @@ public interface ServerConfigServicesLookup {
     public List<ComputedServerConfigValueService> getComputed();
 
     public List<ServerConfigMatcherService> getMatchers();
+    
+    public List<ManifestContributor> getContributors();
 }
