@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,14 +50,21 @@
 package com.openexchange.appsuite.osgi;
 
 import java.io.File;
-import java.text.MessageFormat;
 import org.osgi.framework.BundleException;
 import org.osgi.service.http.HttpService;
 import com.openexchange.ajax.requesthandler.Dispatcher;
+import com.openexchange.appsuite.AppSuiteLoginRampUp;
 import com.openexchange.appsuite.AppsLoadServlet;
+import com.openexchange.appsuite.FileContribution;
+import com.openexchange.appsuite.FileContributor;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.dispatcher.DispatcherPrefixService;
+import com.openexchange.exception.OXException;
+import com.openexchange.login.LoginRampUpService;
 import com.openexchange.osgi.HousekeepingActivator;
+import com.openexchange.osgi.NearRegistryServiceTracker;
+import com.openexchange.threadpool.ThreadPoolService;
+import com.openexchange.tools.session.ServerSession;
 
 /**
  * {@link Activator} - The activator for <code>"com.openexchange.appsuite"</code> bundle.
@@ -66,7 +73,7 @@ public class Activator extends HousekeepingActivator {
 
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { HttpService.class, ConfigurationService.class, DispatcherPrefixService.class };
+        return new Class<?>[] { HttpService.class, ConfigurationService.class, DispatcherPrefixService.class, Dispatcher.class, ThreadPoolService.class };
     }
 
     @Override
@@ -97,5 +104,31 @@ public class Activator extends HousekeepingActivator {
             sb.append(app.getPath());
         }
         logger.info("Servlet path \"apps/load\" successfully registered with \"apps\"={} and \"zoneinfo\"={}", sb.substring(1), zoneinfo.getPath());
+        
+        final NearRegistryServiceTracker<FileContributor> contributorTracker = new NearRegistryServiceTracker<FileContributor>(context, FileContributor.class);
+        rememberTracker(contributorTracker);
+        
+        openTrackers();
+        
+        AppsLoadServlet.contributors = new FileContributor() {
+            
+            @Override
+            public FileContribution getData(ServerSession session, String moduleName) throws OXException {
+                for(FileContributor contributor: contributorTracker.getServiceList()) {
+                    FileContribution contribution = null;
+                    try {
+                        contribution = contributor.getData(session, moduleName);                        
+                    } catch (OXException x) {
+                        
+                    }
+                    if (contribution != null) {
+                        return contribution;
+                    }
+                }
+                return null;
+            }
+        };
+        
+        registerService(LoginRampUpService.class, new AppSuiteLoginRampUp(this));
     }
 }
